@@ -24,6 +24,8 @@
 #' * `flip_pref_suff()` Switches the location of prefix and suffix, such that the prefix becomes the suffix, and
 #'                      the suffix becomes the prefix.
 #'                      E.g., "a -> b" becomes "b -> a" or "a \[b\]" becomes "b \[a\]".
+#' * `keep_pref_suff()` Selects only prefix or suffix, discarding notational elements 
+#'                      and the rejected part.
 #' * `switch_notation()` Switches from one type of notation to another based on the `from` and `to` arguments.
 #'                       Optionally, prefix and suffix can be `flip`ped.
 #' * `switch_notation_byname()` Switches matrix row and/or column names from one type of notation to another 
@@ -37,31 +39,33 @@
 #' None of the strings in a notation vector are considered part of the prefix or suffix.
 #' E.g., "a -> b" in arrow notation means that "a" is the prefix and "b" is the suffix.
 #'
-#' @param sep a string separator between prefix and suffix. Default is " -> ".
-#' @param pref_start a string indicating the start of a prefix. Default is `NULL`.
-#' @param pref_end a string indicating the end of a prefix. Default is the value of `sep`.
-#' @param suff_start a string indicating the start of a suffix. Default is the value of `sep`.
-#' @param suff_end a string indicating the end of a suffix. Default is `NULL`.
-#' @param x a string or list of strings to be operated upon.
-#' @param pref a string or list of strings that are prefixes. Default is `NULL`.
-#' @param suff a string of list of strings that are suffixes. Default is `NULL`.
-#' @param ps a list of prefixes and suffixes in which each item of the list is itself a list with two items named `pref` and `suff`.
-#' @param notation a notation vector generated by one of the `*_notation()` functions, such as
+#' @param sep A string separator between prefix and suffix. Default is " -> ".
+#' @param pref_start A string indicating the start of a prefix. Default is `NULL`.
+#' @param pref_end A string indicating the end of a prefix. Default is the value of `sep`.
+#' @param suff_start A string indicating the start of a suffix. Default is the value of `sep`.
+#' @param suff_end A string indicating the end of a suffix. Default is `NULL`.
+#' @param x A string or list of strings to be operated upon.
+#' @param pref A string or list of strings that are prefixes. Default is `NULL`.
+#' @param suff A string of list of strings that are suffixes. Default is `NULL`.
+#' @param keep Tells which 
+#' @param ps A list of prefixes and suffixes in which each item of the list is itself a list with two items named `pref` and `suff`.
+#' @param notation A notation vector generated by one of the `*_notation()` functions, such as
 #'                 `notation_vec()`, `arrow_notation()`, or `bracket_notation()`. 
 #'                 Default is `arrow_notation()`.
-#' @param from the `notation` to switch _away from_.
-#' @param to the `notation` to switch _to_.
-#' @param flip a boolean that tells whether to also flip the notation. Default is `FALSE`.
-#' @param a a matrix or list of matrices whose row and/or column notation is to be changed.
+#' @param from The `notation` to switch _away from_.
+#' @param to The `notation` to switch _to_.
+#' @param flip A boolean that tells whether to also flip the notation. Default is `FALSE`.
+#' @param a A matrix or list of matrices whose row and/or column notation is to be changed.
 #' @param margin `1` for rows, `2` for columns, or `c(1, 2)` for both rows and columns. Default is `c(1, 2)`.
 #'
-#' @return for `notation_vec()`, `arrow_notation()`, and `bracket_notation()`, 
+#' @return For `notation_vec()`, `arrow_notation()`, and `bracket_notation()`, 
 #'           a string vector with named items `pref_start`, `pref_end`, `suff_start`, and `suff_end`;
-#'         for `split_pref_suff()`, a string list with named items `pref` and `suff`; 
-#'         for `paste_pref_suff()`, `slip_pref_suff()`, and `switch_notation()`, 
+#'         For `split_pref_suff()`, a string list with named items `pref` and `suff`.
+#'         For `paste_pref_suff()`, `split_pref_suff()`, and `switch_notation()`, 
 #'           a string list in notation format specified by various `notation` arguments, including
-#'           `from`, and `to`, 
-#'         for `switch_row_col_notation_byname()`, matrices with row and column names with switched notation, 
+#'           `from`, and `to`.
+#'         For `keep_pref_suff`, one of the prefix or suffix or a list of prefixes or suffixes.
+#'         For `switch_row_col_notation_byname()`, matrices with row and column names with switched notation, 
 #'           per arguments.
 #'
 #' @examples
@@ -70,6 +74,7 @@
 #' bracket_notation()
 #' split_pref_suff("a -> b", notation = arrow_notation())
 #' flip_pref_suff("a [b]", notation = bracket_notation())
+#' keep_pref_suff("a -> b", keep = "suff", notation = arrow_notation())
 #' switch_notation("a -> b", from = arrow_notation(), to = bracket_notation())
 #' switch_notation("a -> b", from = arrow_notation(), to = bracket_notation(), 
 #'                 flip = TRUE)
@@ -216,6 +221,30 @@ flip_pref_suff <- function(x, notation = arrow_notation()) {
 }
 
 
+#' @export
+#' @rdname row-col-notation
+keep_pref_suff <- function(x, keep = c("pref", "suff"), notation) {
+  keep <- match.arg(keep)
+  
+  choose_pref_or_suff <- function(ps, which_to_keep) {
+    # ps should be an item with "pref" and "suff" named elements.
+    if (which_to_keep == "pref" | ps[["suff"]] == "") {
+      return(ps[["pref"]])
+    }
+    return(ps[["suff"]])
+  }
+
+  pref_suff <- split_pref_suff(x, notation)
+  if (length(x) > 1) {
+    out <- lapply(pref_suff, choose_pref_or_suff, keep) %>% 
+      unlist()
+  } else {
+    out <- choose_pref_or_suff(pref_suff, keep)
+  }
+  return(out)
+}
+
+
 #' @export
 #' @rdname row-col-notation
 switch_notation <- function(x, from, to, flip = FALSE) {
